document.addEventListener("DOMContentLoaded", function() {
    let thread_id = null; // Variable to store the OpenAI thread ID for this chat session.

    /**
     * 1. Create a new OpenAI thread when the chatbox loads.
     *    This is done by sending an AJAX request to the WordPress backend (admin-ajax.php).
     */
fetch(wp_chatbot_ajax.ajaxurl, {
    method: "POST",
    headers: { 
        "Content-Type": "application/x-www-form-urlencoded",
        "OpenAI-Beta": "assistants=v2"  // Required for API v2
    },
    body: "action=wp_chatbot_create_thread"
})
.then(response => {
    console.log("Raw Fetch Response:", response); // Logs the raw response object
    return response.text(); // Get response as text before JSON parsing
})
.then(text => {
    console.log("Raw Response Text:", text); // Logs the raw response content
    return JSON.parse(text); // Attempt to parse JSON manually
})
.then(data => {
    console.log("Parsed JSON Data:", data); // Logs the parsed JSON response
    if (data.success) {
        thread_id = data.data.thread_id;
        console.log("New Thread ID:", thread_id);
    } else {
        console.error("Failed to create thread:", data.error);
    }
})
.catch(error => console.error("Error creating thread:", error));


    // Select the chatbot input, send button, and message display area
    const chatbotInput = document.getElementById("wp-chatbot-input");
    const chatbotSend = document.getElementById("wp-chatbot-send");
    const chatbotMessages = document.getElementById("wp-chatbot-messages");

    // Add event listener to the send button
    chatbotSend.addEventListener("click", sendMessage);

    // Allow pressing Enter to send a message
    chatbotInput.addEventListener("keypress", function(event) {
        if (event.key === "Enter") sendMessage();
    });

    /**
     * 2. Function to send a user message to OpenAI.
     *    - It sends the message to an existing OpenAI thread (using `thread_id`).
     */
function sendMessage() {
    if (!thread_id) { // Ensure thread_id is set
        console.error("No thread ID available.");
        return;
    }

    let userMessage = chatbotInput.value.trim();
    if (!userMessage) return;

    // Display user message in the chat window
    chatbotMessages.innerHTML += `<div class='chatbot-message user'>${userMessage}</div>`;
    chatbotInput.value = ""; // Clear input field after sending

    // Show the loading indicator
    document.getElementById("wp-chatbot-loader").style.display = "flex";
    
// Scroll to bottom after user message is added
    scrollToBottom();
    
    fetch(wp_chatbot_ajax.ajaxurl, {
        method: "POST",
        headers: { "Content-Type": "application/x-www-form-urlencoded" },
        body: `action=wp_chatbot_send&message=${encodeURIComponent(userMessage)}&thread_id=${encodeURIComponent(thread_id)}`
    })
    .then(response => {
        console.log("Raw Fetch Response:", response);
        return response.text();
    })
    .then(text => {
        console.log("Raw Response Text:", text);
        return JSON.parse(text);
    })
    .then(data => {
        console.log("Parsed JSON Data:", data);

        // Hide the loading indicator after response is received
        document.getElementById("wp-chatbot-loader").style.display = "none";

        if (data.success) {
            let assistantResponse = "No response received";

            if (data.data.response && data.data.response.length > 0) {
                assistantResponse = data.data.response;
            }

 
            
            chatbotMessages.innerHTML += `<div class='chatbot-message ai'>${assistantResponse}</div>`;
           
        } else {
            chatbotMessages.innerHTML += `<div class='chatbot-message error'>Error: ${data.error}</div>`;
        }
    })
    .catch(error => {
        console.error("Fetch Error:", error);
        chatbotMessages.innerHTML += `<div class='chatbot-message error'>Error: ${error.message}</div>`;

        // Hide the loading indicator if an error occurs
        document.getElementById("wp-chatbot-loader").style.display = "none";
    });
}
// ✅ Function to scroll the chatbox to the bottom
function scrollToBottom() {
    let chatbox = document.getElementById("wp-chatbot-messages");
    chatbox.scrollTop = chatbox.scrollHeight;
}

});
document.addEventListener("DOMContentLoaded", function() {
    let chatbotContainer = document.getElementById("wp-chatbot-container");
    let chatbotAvatar = document.getElementById("wp-chatbot-avatar");
    let chatbotClose = document.getElementById("wp-chatbot-close");

    // Show chatbox when avatar is clicked
    chatbotAvatar.addEventListener("click", function() {
        chatbotContainer.style.display = "block";
    });

    // Close chatbox when close button is clicked
    chatbotClose.addEventListener("click", function() {
        chatbotContainer.style.display = "none";
    });
});
document.addEventListener("DOMContentLoaded", function() {
    let chatbotContainer = document.getElementById("wp-chatbot-container");
    let chatbotAvatar = document.getElementById("wp-chatbot-avatar");
    let chatbotClose = document.getElementById("wp-chatbot-close");
    let chatbotFullscreen = document.getElementById("wp-chatbot-fullscreen");

    // Show chatbox when avatar is clicked
    chatbotAvatar.addEventListener("click", function() {
        chatbotContainer.style.display = "block";
    });

    // Close chatbox when close button is clicked
    chatbotClose.addEventListener("click", function() {
        chatbotContainer.style.display = "none";
    });

    // Toggle full-screen mode
    chatbotFullscreen.addEventListener("click", function() {
        chatbotContainer.classList.toggle("fullscreen");

        // Change button icon based on mode
        if (chatbotContainer.classList.contains("fullscreen")) {
            chatbotFullscreen.innerHTML = "⤡"; // Exit full screen symbol
        } else {
            chatbotFullscreen.innerHTML = "⛶"; // Enter full screen symbol
        }
    });
});

document.addEventListener("DOMContentLoaded", function() {
    let thread_id = getCookie("chatbot_thread_id");

    if (thread_id && thread_id.startsWith("thread_")) {
        console.log("✅ Reusing existing thread:", thread_id);
        
        fetchChatHistory(thread_id);
    } else {
        console.log("🆕 No valid thread found, creating a new one...");
        
        fetch(wp_chatbot_ajax.ajaxurl, {
            method: "POST",
            headers: { "Content-Type": "application/x-www-form-urlencoded" },
            body: "action=wp_chatbot_create_thread"
        })
        .then(response => response.json())
        .then(data => {
            if (data.success && data.thread_id.startsWith("thread_")) {
                thread_id = data.thread_id;
                console.log("✅ New Thread Created:", thread_id);
                setCookie("chatbot_thread_id", thread_id, 30); // Store for 30 minutes
                fetchChatHistory(thread_id); // Fetch messages now that thread is valid
            } else {
                console.error("❌ Failed to create thread:", data.error);
            }
        })
        .catch(error => console.error("❌ Error creating thread:", error));
    }

    // Function to set a cookie
    function setCookie(name, value, minutes) {
        let expires = new Date();
        expires.setTime(expires.getTime() + (minutes * 60 * 1000));
        document.cookie = name + "=" + value + "; expires=" + expires.toUTCString() + "; path=/";
    }

    // Function to get a cookie
    function getCookie(name) {
        let nameEQ = name + "=";
        let cookies = document.cookie.split(";");
        for (let i = 0; i < cookies.length; i++) {
            let c = cookies[i].trim();
            if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length);
        }
        return null;
    }
});

function fetchChatHistory(thread_id) {
    fetch(wp_chatbot_ajax.ajaxurl, {
        method: "POST",
        headers: { "Content-Type": "application/x-www-form-urlencoded" },
        body: `action=wp_chatbot_fetch_history&thread_id=${encodeURIComponent(thread_id)}`
    })
    .then(response => response.json())
    .then(data => {
        console.log("📜 Raw Chat History Response:", data); // Log full response

        if (!data.success || !data.data || !Array.isArray(data.data.messages)) {
            console.error("❌ Error fetching chat history:", data.error || "Invalid response format");
            return;
        }

        console.log("✅ Chat history messages before reversal:", data.data.messages);

        let chatbotMessages = document.getElementById("wp-chatbot-messages");
        chatbotMessages.innerHTML = ""; // Clear chatbox

        // Reverse messages so the latest appears at the bottom
        let reversedMessages = data.data.messages.reverse();
        console.log("🔄 Reversed Chat history messages:", reversedMessages);

        reversedMessages.forEach((msg, index) => {
            let messageClass = (index % 2 === 0) ? "chatbot-message user" : "chatbot-message ai"; // Ensure correct user-assistant order
            chatbotMessages.innerHTML += `<div class='${messageClass}'>${msg}</div>`;
        });

        scrollToBottom();
    })
    .catch(error => console.error("❌ Fetch Error:", error));
}

function scrollToBottom() {
    let chatbotMessages = document.getElementById("wp-chatbot-messages");
    if (chatbotMessages) {
        chatbotMessages.scrollTop = chatbotMessages.scrollHeight;
    }
}

document.addEventListener("DOMContentLoaded", function () {
    let defaultQuestionButton = document.getElementById("wp-chatbot-default-question");
    let inputField = document.getElementById("wp-chatbot-input");
    let sendButton = document.getElementById("wp-chatbot-send");

    if (defaultQuestionButton) {
        defaultQuestionButton.addEventListener("click", function () {
            inputField.value = defaultQuestionButton.innerText;
            sendButton.click();
        });
    }
});
document.addEventListener("DOMContentLoaded", function () {
    function hexToRgb(hex) {
        hex = hex.replace(/^#/, '');
        let bigint = parseInt(hex, 16);
        let r = (bigint >> 16) & 255;
        let g = (bigint >> 8) & 255;
        let b = bigint & 255;
        return r + "," + g + "," + b;
    }

    if (wp_chatbot_ajax.background_color) {
        document.documentElement.style.setProperty("--chatbot-bg-color", wp_chatbot_ajax.background_color);
        document.documentElement.style.setProperty("--chatbot-bg-color-rgb", hexToRgb(wp_chatbot_ajax.background_color));
    }

    if (wp_chatbot_ajax.text_color) {
        document.documentElement.style.setProperty("--chatbot-text-color", wp_chatbot_ajax.text_color);
    }
});






