<?php
// Add submenu in the WordPress admin panel
function chatbot_admin_menu() {
    add_submenu_page(
        'options-general.php',      // Parent menu (Settings)
        'Chatbot Content Export',   // Page title
        'Chatbot Export',           // Menu title
        'manage_options',           // Capability
        'chatbot-export',           // Menu slug
        'chatbot_export_page'       // Callback function
    );
}
add_action('admin_menu', 'chatbot_admin_menu');

// Display admin page content
function chatbot_export_page() {
    ?>
    <div class="wrap">
        <h2>Export Website Content for Chatbot</h2>
        
        <p style="background: #f1f1f1; padding: 10px; border-left: 4px solid #0073aa;">
            <strong>Select all pages and posts from the list below to create a text data file for training the assistant.</strong><br>
            Once downloaded, upload the file to the assistant in the OpenAI Assistants page: 
            <a href="https://platform.openai.com/playground/assistants" target="_blank">
                https://platform.openai.com/playground/assistants
            </a>.
        </p>

        <form method="post" action="<?php echo admin_url('admin-post.php'); ?>">
            <input type="hidden" name="action" value="chatbot_export">
            <?php
            // Get all posts and pages
            $args = array(
                'post_type' => array('post', 'page'),
                'posts_per_page' => -1
            );
            $posts = get_posts($args);

            if ($posts) {
                echo '<ul>';
                foreach ($posts as $post) {
                    echo '<li><input type="checkbox" name="chatbot_selected_posts[]" value="' . $post->ID . '"> ' . esc_html($post->post_title) . '</li>';
                }
                echo '</ul>';
                submit_button('Generate and Download');
            } else {
                echo '<p>No posts or pages found.</p>';
            }
            ?>
        </form>
    </div>
    <?php
}


// Handle form submission and generate .txt file
function chatbot_export_generate_file() {
    if (!current_user_can('manage_options')) {
        wp_die(__('You do not have permission to perform this action.'));
    }

    if (isset($_POST['chatbot_selected_posts'])) {
        $selected_posts = $_POST['chatbot_selected_posts'];
        $content = "";

        foreach ($selected_posts as $post_id) {
            $post = get_post($post_id);
            if ($post) {
                $content .= strip_tags($post->post_title) . "\n";
                $content .= strip_tags($post->post_content) . "\n\n";
            }
        }

        // Generate a filename based on the website URL
        $site_url = parse_url(get_site_url(), PHP_URL_HOST);
        $file_name = sanitize_file_name($site_url . '-assistant-data.txt');

        // Save the file in the uploads directory
        $upload_dir = wp_upload_dir();
        $file_path = $upload_dir['path'] . '/' . $file_name;
        file_put_contents($file_path, $content);

        // Redirect back to admin page with download link
        wp_redirect(admin_url('options-general.php?page=chatbot-export&chatbot_download=1&file=' . urlencode($file_name)));
        exit;
    }
}

add_action('admin_post_chatbot_export', 'chatbot_export_generate_file');

// Display download link if available
function chatbot_export_download_link() {
    if (isset($_GET['chatbot_download']) && $_GET['chatbot_download'] == 1 && isset($_GET['file'])) {
        $upload_dir = wp_upload_dir();
        $file_url = $upload_dir['url'] . '/' . $_GET['file'];
        echo '<div class="updated"><p>Download your file: <a href="' . esc_url($file_url) . '" download>Download</a></p></div>';
    }
}
add_action('admin_notices', 'chatbot_export_download_link');

?>
