<?php
/**
 * Plugin Name: WP Chatbot Assistant
 * Description: Displays an AI chatbot using OpenAI Assistants API.
 * Version: 1.0.0
 * Author: Tony Marriott
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

// Define plugin path
define('WP_CHATBOT_ASSISTANT_DIR', plugin_dir_path(__FILE__));
define('WP_CHATBOT_ASSISTANT_URL', plugin_dir_url(__FILE__));

// Include API handling
include_once WP_CHATBOT_ASSISTANT_DIR . 'includes/chatbot-api.php';

// Enqueue scripts
function wp_chatbot_enqueue_scripts() {
    wp_enqueue_script('wp-chatbot-script', WP_CHATBOT_ASSISTANT_URL . 'assets/chatbot.js', ['jquery'], null, true);
    
    // Corrected way to pass ajaxurl
    wp_localize_script('wp-chatbot-script', 'wp_chatbot_ajax', [
    'ajaxurl' => admin_url('admin-ajax.php'),
    'assistant_name' => get_option('wp_chatbot_assistant_name', 'AI Assistant'),
    'background_color' => get_option('wp_chatbot_background_color', '#0073aa'),
    'text_color' => get_option('wp_chatbot_text_color', '#ffffff'),
]);



    wp_enqueue_style('wp-chatbot-style', WP_CHATBOT_ASSISTANT_URL . 'assets/chatbot.css');
}
add_action('wp_enqueue_scripts', 'wp_chatbot_enqueue_scripts');



// Add chatbot HTML to footer
function wp_chatbot_display_chatbox() {
    $chatbox_title = get_option('wp_chatbot_title', 'Chat with AI');
    $assistant_name = get_option('wp_chatbot_assistant_name', 'AI Assistant');
    $chatbox_placeholder = get_option('wp_chatbot_placeholder', 'Type your message...');
    $default_question = get_option('wp_chatbot_default_question', ''); // Get the default question

    // Get the assistant avatar image
    $avatar_url = plugins_url('images/default-assistant-image.png', __FILE__);
    $image_url = plugins_url('images/writing.gif', __FILE__);

    echo '<div id="wp-chatbot-avatar-container">
            <img src="' . esc_url($avatar_url) . '" alt="Assistant Avatar" id="wp-chatbot-avatar">
          </div>

          <div id="wp-chatbot-container" class="hidden">
            <div id="wp-chatbot-header">
                <img src="' . esc_url($avatar_url) . '" alt="Assistant Avatar" id="wp-chatbot-header-avatar">
                <span>' . esc_html($chatbox_title) . '</span>
                <div class="wp-chatbot-buttons">
                    <button id="wp-chatbot-close" title="Close">&times;</button>
                </div>
            </div>
            <div id="wp-chatbot-messages">
                <div class="chatbot-intro">
                    <p><strong>Welcome to ' . esc_html($chatbox_title) . '!</strong></p>
                    <p>You are chatting with <strong>' . esc_html($assistant_name) . '</strong>.</p>
                </div>
            </div>
            <div id="wp-chatbot-loader" class="hidden">
                <img src="' . esc_url($image_url) . '" alt="Chatbot is thinking..." id="wp-chatbot-writing"/>
            </div>
            <div id="wp-chatbot-input-container">
            <input type="text" id="wp-chatbot-input" placeholder="' . esc_attr($chatbox_placeholder) . '">
            <button id="wp-chatbot-send">Send</button>
            </div>
            ';
            

    // Add the default question button if it exists
    if (!empty($default_question)) {
        echo '<button id="wp-chatbot-default-question" class="wp-chatbot-default-button">' . esc_html($default_question) . '</button>';
    }

    echo '</div>';
}







add_action('wp_footer', 'wp_chatbot_display_chatbox');

// Hook to add the admin menu
add_action('admin_menu', 'wp_chatbot_add_admin_menu');

function wp_chatbot_add_admin_menu() {
    add_options_page(
        'Chatbot Settings',  // Page title
        'Chatbot Assistant', // Menu title
        'manage_options',    // Capability
        'wp-chatbot-settings', // Slug
        'wp_chatbot_settings_page' // Callback function
    );
}

// Function to display the settings page
function wp_chatbot_settings_page() {
    ?>
    <div class="wrap">
        <h1>Chatbot Assistant Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('wp_chatbot_settings_group'); // Security fields
            do_settings_sections('wp-chatbot-settings'); // Display sections
            submit_button(); // Save button
            ?>
        </form>
    </div>
    <?php
}

// Hook to initialize settings
add_action('admin_init', 'wp_chatbot_register_settings');

// Hook to initialize settings
add_action('admin_init', 'wp_chatbot_register_settings');

// Hook to initialize settings
add_action('admin_init', 'wp_chatbot_register_settings');

function wp_chatbot_register_settings() {
    // Register existing settings
    register_setting('wp_chatbot_settings_group', 'wp_chatbot_openai_api_key');
    register_setting('wp_chatbot_settings_group', 'wp_chatbot_assistant_id');
    register_setting('wp_chatbot_settings_group', 'wp_chatbot_title');
    register_setting('wp_chatbot_settings_group', 'wp_chatbot_assistant_name');
    register_setting('wp_chatbot_settings_group', 'wp_chatbot_placeholder');
    register_setting('wp_chatbot_settings_group', 'wp_chatbot_default_question');

    // Register new color settings
    register_setting('wp_chatbot_settings_group', 'wp_chatbot_background_color');
    register_setting('wp_chatbot_settings_group', 'wp_chatbot_text_color');

    add_settings_section('wp_chatbot_main_section', 'Chatbot Settings', null, 'wp-chatbot-settings');

    // Existing settings
    add_settings_field('wp_chatbot_openai_api_key', 'OpenAI API Key', 'wp_chatbot_openai_api_key_callback', 'wp-chatbot-settings', 'wp_chatbot_main_section');
    add_settings_field('wp_chatbot_assistant_id', 'OpenAI Assistant ID', 'wp_chatbot_assistant_id_callback', 'wp-chatbot-settings', 'wp_chatbot_main_section');
    add_settings_field('wp_chatbot_title', 'Chatbox Title', 'wp_chatbot_title_callback', 'wp-chatbot-settings', 'wp_chatbot_main_section');
    add_settings_field('wp_chatbot_assistant_name', 'Assistant Name', 'wp_chatbot_assistant_name_callback', 'wp-chatbot-settings', 'wp_chatbot_main_section');
    add_settings_field('wp_chatbot_placeholder', 'Chatbox Placeholder', 'wp_chatbot_placeholder_callback', 'wp-chatbot-settings', 'wp_chatbot_main_section');
    add_settings_field('wp_chatbot_default_question', 'Initial Default Question', 'wp_chatbot_default_question_callback', 'wp-chatbot-settings', 'wp_chatbot_main_section');

    // New color settings
    add_settings_field('wp_chatbot_background_color', 'Chatbox Background Color', 'wp_chatbot_background_color_callback', 'wp-chatbot-settings', 'wp_chatbot_main_section');
    add_settings_field('wp_chatbot_text_color', 'Chatbox Text Color', 'wp_chatbot_text_color_callback', 'wp-chatbot-settings', 'wp_chatbot_main_section');
}
// Callback function to render Background Color input
function wp_chatbot_background_color_callback() {
    $background_color = get_option('wp_chatbot_background_color', '#0073aa'); // Default to blue
    echo '<input type="color" name="wp_chatbot_background_color" value="' . esc_attr($background_color) . '">';
}

// Callback function to render Text Color input
function wp_chatbot_text_color_callback() {
    $text_color = get_option('wp_chatbot_text_color', '#ffffff'); // Default to white
    echo '<input type="color" name="wp_chatbot_text_color" value="' . esc_attr($text_color) . '">';
}


// Callback function to render Default Question input
function wp_chatbot_default_question_callback() {
    $default_question = get_option('wp_chatbot_default_question', '');
    echo '<input type="text" name="wp_chatbot_default_question" value="' . esc_attr($default_question) . '" class="regular-text">';
    echo '<p class="description">Enter an initial default question. This question will appear as a button next to the SEND button in the chatbox.</p>';
}


// Callback functions to render input fields
function wp_chatbot_title_callback() {
    $title = get_option('wp_chatbot_title', 'Chat with AI');
    echo '<input type="text" name="wp_chatbot_title" value="' . esc_attr($title) . '" class="regular-text">';
}

function wp_chatbot_assistant_name_callback() {
    $assistant_name = get_option('wp_chatbot_assistant_name', 'AI Assistant');
    echo '<input type="text" name="wp_chatbot_assistant_name" value="' . esc_attr($assistant_name) . '" class="regular-text">';
}

function wp_chatbot_placeholder_callback() {
    $placeholder = get_option('wp_chatbot_placeholder', 'Type your message...');
    echo '<input type="text" name="wp_chatbot_placeholder" value="' . esc_attr($placeholder) . '" class="regular-text">';
}

// Callback function to render OpenAI API Key input
function wp_chatbot_openai_api_key_callback() {
    $api_key = get_option('wp_chatbot_openai_api_key');
    echo '<input type="text" name="wp_chatbot_openai_api_key" value="' . esc_attr($api_key) . '" class="regular-text">';
}

// Callback function to render Assistant ID input
function wp_chatbot_assistant_id_callback() {
    $assistant_id = get_option('wp_chatbot_assistant_id');
    echo '<input type="text" name="wp_chatbot_assistant_id" value="' . esc_attr($assistant_id) . '" class="regular-text">';
}

// Include the admin page for post selection and content extraction
if (is_admin()) {
    require_once plugin_dir_path(__FILE__) . 'includes/admin-page.php';
}
